@@ -31,5 +31,12 @@ withr::with_options(
       params <- model_parameters(m2)
       expect_snapshot(params)
     })
+
+    skip_on_os(c("mac", "linux"))
+    test_that("simulate_parameters.mblogit", {
+      set.seed(1234)
+      params <- simulate_parameters(m2)
+      expect_snapshot(params)
+    })
   }
 )
